@@ -1,22 +1,13 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2005-2007 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2005-2009 -- leonerd@leonerd.org.uk
 
-package FCGI::Async::Constants;
+package # hide from CPAN
+   FCGI::Async::Constants;
 
 use strict;
-
-=head1 NAME
-
-FCGI::Async::Constants - A module containing FastCGI protocol constants
-
-=head1 SYNOPSIS
-
-It should not be necessary to use this module directly; it is used internally
-by other L<FCGI::Async> modules to share protocol constants.
-
-=cut
+use warnings;
 
 # A large number of constants
 my %constants = (
